@@ -371,7 +371,6 @@ static cairo_surface_t *
 pdf_document_render (EvDocument      *document,
 		     EvRenderContext *rc)
 {
-	PdfDocument *pdf_document;
 	PopplerPage *poppler_page;
 	double width_points, height_points;
 	gint width, height;
@@ -416,11 +415,9 @@ static GdkPixbuf *
 pdf_document_get_thumbnail (EvDocument      *document,
 			    EvRenderContext *rc)
 {
-	PdfDocument *pdf_document = PDF_DOCUMENT (document);
 	PopplerPage *poppler_page;
 	cairo_surface_t *surface;
 	GdkPixbuf *pixbuf = NULL;
-	GdkPixbuf *border_pixbuf;
 	double page_width, page_height;
 	gint width, height;
 
@@ -702,7 +699,6 @@ pdf_document_get_info (EvDocument *document)
 	PopplerPageMode mode;
 	PopplerViewerPreferences view_prefs;
 	PopplerPermissions permissions;
-	EvPage *page;
 	char *metadata;
 	gboolean linearized;
 
@@ -1422,12 +1418,10 @@ pdf_document_images_get_image_mapping (EvDocumentImages *document_images,
 				       EvPage           *page)
 {
 	GList *retval = NULL;
-	PdfDocument *pdf_document;
 	PopplerPage *poppler_page;
 	GList *mapping_list;
 	GList *list;
 
-	pdf_document = PDF_DOCUMENT (document_images);
 	poppler_page = POPPLER_PAGE (page->backend_page);
 	mapping_list = poppler_page_get_image_mapping (poppler_page);
 
@@ -1558,7 +1552,6 @@ pdf_document_file_exporter_begin (EvFileExporter        *exporter,
 	PdfDocument *pdf_document = PDF_DOCUMENT (exporter);
 	PdfPrintContext *ctx;
 #ifdef HAVE_CAIRO_PRINT
-	gdouble width, height;
 	cairo_surface_t *surface = NULL;
 #endif
 	
@@ -1822,8 +1815,6 @@ pdf_document_print_print_page (EvDocumentPrint *document,
 			       EvPage          *page,
 			       cairo_t         *cr)
 {
-	PdfDocument *pdf_document = PDF_DOCUMENT (document);
-
 	poppler_page_render_for_printing (POPPLER_PAGE (page->backend_page), cr);
 }
 
@@ -2077,6 +2068,7 @@ pdf_document_page_transition_iface_init (EvDocumentTransitionInterface *iface)
 }
 
 /* Forms */
+#if 0
 static void
 pdf_document_get_crop_box (EvDocument  *document, 
 			   int          page, 
@@ -2094,6 +2086,7 @@ pdf_document_get_crop_box (EvDocument  *document,
 	rect->y1 = poppler_rect.y1;
 	rect->y2 = poppler_rect.y2;
 }
+#endif
 
 static EvFormField *
 ev_form_field_from_poppler_field (PopplerFormField *poppler_field)
@@ -2566,7 +2559,6 @@ ev_annot_from_poppler_annot (PopplerAnnot *poppler_annot,
 			break;
 	        case POPPLER_ANNOT_FILE_ATTACHMENT: {
 			PopplerAnnotFileAttachment *poppler_annot_attachment;
-			EvAnnotationAttachment     *ev_annot_attachment;
 			PopplerAttachment          *poppler_attachment;
 			gchar                      *data = NULL;
 			gsize                       size;
@@ -2797,8 +2789,6 @@ pdf_document_annotations_add_annotation (EvDocumentAnnotations *document_annotat
 	gdouble          height;
 	PopplerColor     poppler_color;
 	GdkColor         color;
-	time_t           utime;
-	gchar           *modified;
 	gchar           *name;
 
 	pdf_document = PDF_DOCUMENT (document_annotations);
@@ -3170,7 +3160,6 @@ static void
 pdf_document_layers_show_layer (EvDocumentLayers *document,
 				EvLayer          *layer)
 {
-	PdfDocument  *pdf_document = PDF_DOCUMENT (document);
 	PopplerLayer *poppler_layer;
 
 	poppler_layer = POPPLER_LAYER (g_object_get_data (G_OBJECT (layer), "poppler-layer"));
@@ -3181,7 +3170,6 @@ static void
 pdf_document_layers_hide_layer (EvDocumentLayers *document,
 				EvLayer          *layer)
 {
-	PdfDocument  *pdf_document = PDF_DOCUMENT (document);
 	PopplerLayer *poppler_layer;
 
 	poppler_layer = POPPLER_LAYER (g_object_get_data (G_OBJECT (layer), "poppler-layer"));
@@ -3192,7 +3180,6 @@ static gboolean
 pdf_document_layers_layer_is_visible (EvDocumentLayers *document,
 				      EvLayer          *layer)
 {
-	PdfDocument  *pdf_document = PDF_DOCUMENT (document);
 	PopplerLayer *poppler_layer;
 
 	poppler_layer = POPPLER_LAYER (g_object_get_data (G_OBJECT (layer), "poppler-layer"));
